def resultat_requete(ma_requete):
    """
    Renvoie le resultat de la requete 'ma_requete' donnee sous forme d'une 
    chaine de caractere. Le resultat est renvoye sous forme d'une liste de 
    mutiplets (appeles 'tuple' en Python et qui ne sont en fait que des listes 
    non modifiales), chaque ligne du resultat de la requete correspond a une 
    sous-liste de la liste principale renvoyee. Exemple:

    >>> resultat_requete('SELECT nom,temps,altitude FROM satellite LIMIT 2')
    [('ACRIMSAT',0,679.607),('ACRIMSAT',69,681.301)]

    """
    import sqlite3
    # Ouverture de la base et execution de la commande
    conn = sqlite3.connect('satellites.sqlite')
    c = conn.cursor()
    c.execute(ma_requete)
    rows = c.fetchall()
    conn.commit()
    conn.close()
    return rows

import numpy as np
import matplotlib.pyplot as plt

def RT(latitude):
    """
    Evolution du rayon de la Terre en fonction de la latitude (donnee en 
    degres, c'est-a-dire comme elle est stockee dans la base de donnees).
    Renvoie le rayon terrestre a la latitude demandee en km.
    """
    a = 6378.1370               # Rayon equatorial en km
    b = 6356.7523               # Rayon polaire en km
    ph = latitude * np.pi / 180 # Conversion en radians
    return np.sqrt(((a**2*np.cos(ph))**2+(b**2*np.sin(ph))**2)/((a*np.cos(ph))**2+(b*np.sin(ph))**2))

# Exemple d'utilisation 
req = """SELECT temps,altitude FROM satellite WHERE nom='ACRIMSAT'"""
# On peut convertir en array car il n'y a pas de chaine de caracteres dans le 
# resultat. Ce sera plus facile pour recuperer et traiter chaque colonne.
res = np.array(resultat_requete(req)) 
t = res[:,0] # Premiere colonne
a = res[:,1] # Deuxieme colonne
print(res)
plt.plot(t,a)
plt.xlabel('Temps en secondes')
plt.ylabel('Altitude en km')
plt.title('Altitude en fonction du temps pour le satellite ACRIMSAT')
plt.show()

